@@ -25,9 +25,11 @@ namespace Analitza
 {
 
 /**
- *	This class represents the string expression writer.
+ * \class HtmlExpressionWriter
+ * 
+ * \ingroup AnalitzaModule
  *
- *	@author Aleix Pol <aleixpol@kde.org>  
+ * \brief This class represents the string expression writer.
  */
 
 class HtmlExpressionWriter : public ExpressionWriter
@@ -43,6 +45,8 @@ class HtmlExpressionWriter : public ExpressionWriter
 		virtual QString accept(const List* l);
 		virtual QString accept(const Apply* a);
 		virtual QString accept(const CustomObject* c);
+		virtual QString accept(const Matrix* c);
+		virtual QString accept(const MatrixRow* c);
 		
 		QString result() const { return m_result; }
 		
